==> seedsui-react-5.0.7.tgz: package/es/Container/ContainerPull/index.js <==
var _excluded = ["onTopRefresh", "onBottomRefresh", "refreshing", "children"];

function _extends() { _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }

function _objectWithoutPropertiesLoose(source, excluded) { if (source == null) return {}; var target = {}; var sourceKeys = Object.keys(source); var key, i; for (i = 0; i < sourceKeys.length; i++) { key = sourceKeys[i]; if (excluded.indexOf(key) >= 0) continue; target[key] = source[key]; } return target; }

import React, { forwardRef, useRef, useImperativeHandle, useEffect, useContext } from 'react';
import Container from './../Container';
import Instance from './instance.js';
import locale from './../../locale';
var ContainerPull = forwardRef(function (_ref, ref) {
  var onTopRefresh = _ref.onTopRefresh,
      onBottomRefresh = _ref.onBottomRefresh,
      refreshing = _ref.refreshing,
      children = _ref.children,
      others = _objectWithoutPropertiesLoose(_ref, _excluded);

  // 因为在click事件内改变数据的可能性, 所以更新句柄, 防止synchronization模式读取创建时的状态
  var refreshingRef = useRef({
    current: refreshing
  });
  refreshingRef.current = refreshing;
  var rootRef = useRef(null);
  var topContainerRef = useRef(null);
  useImperativeHandle(ref, function () {
    return rootRef.current;
  });
  var instance = useRef(null); // 更新句柄, 防止synchronization模式, 每次组件在render的时候都生成上次render的state、function、effects

  if (instance.current) {
    // 头部刷新,加载第一页
    if (onTopRefresh) {
      instance.current.params.onTopRefresh = onTopRefresh;
    } // 底部刷新,加载下一页


    if (onBottomRefresh) {
      instance.current.params.onBottomRefresh = bottomRefresh;
    }
  } // 初始化


  if (refreshingRef.current === 0) refreshingRef.current = false;else if (refreshingRef.current === 1) refreshingRef.current = true;
  useEffect(function () {
    instance.current = new Instance({
      // threshold: 100,
      // end: 200, // 头部下拉的结束位置
      // endRefresh: null, // 滑动到指位置后自动刷新
      // moveTimeout: 0, // 滑动超时, 解决ios手指滑动到原生tabbar上, 不触发onTouchEnd
      container: rootRef.current,
      onScroll: others.onScroll ? others.onScroll : null,
      onTopRefresh: onTopRefresh,
      // 头部刷新,加载第一页
      onBottomRefresh: onBottomRefresh ? bottomRefresh : null,
      // 底部刷新,加载下一页
      // 构建实体
      topContainer: onTopRefresh ? topContainerRef.current : null,
      // 实体交互
      duration: 150,
      onPull: function onPull(e) {
        var topContainer = e.topContainer;
        topContainer.style.height = e.touches.currentPosY + 'px';
        var topIcon = topContainer.querySelector('.containerpull-pull-icon');
        var topCaption = topContainer.querySelector('.containerpull-pull-caption');

        if (!e.isLoading) {
          if (e.touches.currentPosY >= e.params.threshold) {
            if (topIcon) topIcon.classList.add('containerpull-pull-icon-down');
            if (topCaption) topCaption.innerHTML = locale('释放立即刷新', 'release');
          } else {
            if (topIcon) topIcon.classList.remove('containerpull-pull-icon-down');
            if (topCaption) topCaption.innerHTML = locale('下拉可以刷新', 'pull_down');
          }
        }
      },
      onShowTop: function onShowTop(e) {
        var topContainer = e.topContainer;
        var topIcon = topContainer.querySelector('.containerpull-pull-icon');
        var topCaption = topContainer.querySelector('.containerpull-pull-caption');
        topContainer.style.height = e.params.threshold + 'px';
        if (topIcon) topIcon.classList.remove('containerpull-pull-icon-down');
        if (topIcon) topIcon.classList.add('containerpull-pull-icon-loading');
        if (topCaption) topCaption.innerHTML = locale('正在刷新...', 'refreshing');
      },
      onHideTop: function onHideTop(e) {
        var topContainer = e.topContainer;
        topContainer.style.height = '0';
      },
      onTopHid: function onTopHid(e) {
        var topContainer = e.topContainer;
        var topIcon = topContainer.querySelector('.containerpull-pull-icon');
        if (topIcon) topIcon.classList.remove('containerpull-pull-icon-down');
        if (topIcon) topIcon.classList.remove('containerpull-pull-icon-loading');
      }
    });
  }, []); // eslint-disable-line
  // 刷新完成, 重置状态

  function refreshed() {
    instance.current.isLoading = false;

    if (instance.current.touches.posY) {
      // 如果头部展开, 则隐藏头部
      instance.current.hideTop(); // 隐藏头部
    }
  } // 底部刷新


  function bottomRefresh() {
    // 如果没有设置刷新状态refreshing, 则不刷新
    if (refreshingRef.current !== true && refreshingRef.current !== false) {
      refreshed();
      return;
    } // 正在刷新不触发底部刷新


    if (refreshingRef.current === true) return; // 刷新完成触发底部刷新

    if (refreshingRef.current === false) {
      onBottomRefresh();
    }
  } // 控制刷新


  var pullRefreshTimeout = useRef();
  useEffect(function () {
    if (!instance.current) return; // 如果没有设置刷新状态refreshing, 则不刷新

    if (refreshingRef.current !== true && refreshingRef.current !== false) {
      refreshed();
      return;
    } // 正在刷新


    if (refreshingRef.current === true) {
      instance.current.isLoading = true;
      return;
    } // 刷新完成


    if (refreshingRef.current === false) {
      // 刷新完成, 重置状态
      refreshed(); // 判断是否没有滚动条, 如果没有滚动条会再次触发onBottomRefresh方法

      if (pullRefreshTimeout.current) {
        window.clearTimeout(pullRefreshTimeout.current);
      } // 底部刷新


      if (!onBottomRefresh) return; // 因为页面渲染需要时间, 所以需要等渲染完成后再判断有无滚动条

      pullRefreshTimeout.current = setTimeout(function () {
        if (!instance.current.hasScroll()) {
          console.log('刷新完成,但没有滚动条,继续加载...');
          bottomRefresh();
        } else if (instance.current.isBottom()) {
          console.log('刷新完成,滚动条在底部,继续加载...');
          bottomRefresh();
        }
      }, 500);
    }
  }, [refreshing]); // eslint-disable-line

  return /*#__PURE__*/React.createElement(Container, _extends({
    ref: rootRef
  }, others), /*#__PURE__*/React.createElement("div", {
    ref: topContainerRef,
    className: "SID-Dragrefresh-TopContainer containerpull-pull"
  }, /*#__PURE__*/React.createElement("div", {
    className: "containerpull-pull-box"
  }, /*#__PURE__*/React.createElement("div", {
    className: "containerpull-pull-icon"
  }), /*#__PURE__*/React.createElement("div", {
    className: "containerpull-pull-caption"
  }, locale('下拉可以刷新', 'pull_down')))), children);
});
export default ContainerPull;

==> seedsui-react-5.5.1.tgz: package/es/Container/ContainerPull/index.js <==
var _excluded = ["onTopRefresh", "onBottomRefresh", "refreshing", "children"];

function _extends() { _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }

function _objectWithoutPropertiesLoose(source, excluded) { if (source == null) return {}; var target = {}; var sourceKeys = Object.keys(source); var key, i; for (i = 0; i < sourceKeys.length; i++) { key = sourceKeys[i]; if (excluded.indexOf(key) >= 0) continue; target[key] = source[key]; } return target; }

import React, { forwardRef, useRef, useImperativeHandle, useEffect, useContext } from 'react';
import Container from './../Container';
import Instance from './instance.js';
import locale from './../../locale';
var ContainerPull = forwardRef(function (_ref, ref) {
  var onTopRefresh = _ref.onTopRefresh,
      onBottomRefresh = _ref.onBottomRefresh,
      refreshing = _ref.refreshing,
      children = _ref.children,
      others = _objectWithoutPropertiesLoose(_ref, _excluded);

  // 因为在click事件内改变数据的可能性, 所以更新句柄, 防止synchronization模式读取创建时的状态
  var refreshingRef = useRef({
    current: refreshing
  });
  refreshingRef.current = refreshing;
  var rootRef = useRef(null);
  var topContainerRef = useRef(null);
  useImperativeHandle(ref, function () {
    return rootRef.current;
  });
  var instance = useRef(null); // 更新句柄, 防止synchronization模式, 每次组件在render的时候都生成上次render的state、function、effects

  if (instance.current) {
    // 头部刷新,加载第一页
    if (onTopRefresh) {
      instance.current.params.onTopRefresh = onTopRefresh;
    } // 底部刷新,加载下一页


    if (onBottomRefresh) {
      instance.current.params.onBottomRefresh = bottomRefresh;
    }
  } // 初始化


  if (refreshingRef.current === 0) refreshingRef.current = false;else if (refreshingRef.current === 1) refreshingRef.current = true;
  useEffect(function () {
    instance.current = new Instance({
      // threshold: 100,
      // end: 200, // 头部下拉的结束位置
      // endRefresh: null, // 滑动到指位置后自动刷新
      // moveTimeout: 0, // 滑动超时, 解决ios手指滑动到原生tabbar上, 不触发onTouchEnd
      container: rootRef.current,
      onScroll: others.onScroll ? others.onScroll : null,
      onTopRefresh: onTopRefresh,
      // 头部刷新,加载第一页
      onBottomRefresh: onBottomRefresh ? bottomRefresh : null,
      // 底部刷新,加载下一页
      // 构建实体
      topContainer: onTopRefresh ? topContainerRef.current : null,
      // 实体交互
      duration: 150,
      onPull: function onPull(e) {
        var topContainer = e.topContainer;
        topContainer.style.height = e.touches.currentPosY + 'px';
        var topIcon = topContainer.querySelector('.containerpull-pull-icon');
        var topCaption = topContainer.querySelector('.containerpull-pull-caption');

        if (!e.isLoading) {
          if (e.touches.currentPosY >= e.params.threshold) {
            if (topIcon) topIcon.classList.add('containerpull-pull-icon-down');
            if (topCaption) topCaption.innerHTML = locale('释放立即刷新', 'release');
          } else {
            if (topIcon) topIcon.classList.remove('containerpull-pull-icon-down');
            if (topCaption) topCaption.innerHTML = locale('下拉可以刷新', 'pull_down');
          }
        }
      },
      onShowTop: function onShowTop(e) {
        var topContainer = e.topContainer;
        var topIcon = topContainer.querySelector('.containerpull-pull-icon');
        var topCaption = topContainer.querySelector('.containerpull-pull-caption');
        topContainer.style.height = e.params.threshold + 'px';
        if (topIcon) topIcon.classList.remove('containerpull-pull-icon-down');
        if (topIcon) topIcon.classList.add('containerpull-pull-icon-loading');
        if (topCaption) topCaption.innerHTML = locale('正在刷新...', 'refreshing');
      },
      onHideTop: function onHideTop(e) {
        var topContainer = e.topContainer;
        topContainer.style.height = '0';
      },
      onTopHid: function onTopHid(e) {
        var topContainer = e.topContainer;
        var topIcon = topContainer.querySelector('.containerpull-pull-icon');
        if (topIcon) topIcon.classList.remove('containerpull-pull-icon-down');
        if (topIcon) topIcon.classList.remove('containerpull-pull-icon-loading');
      }
    });
  }, []); // eslint-disable-line
  // 刷新完成, 重置状态

  function refreshed() {
    instance.current.isLoading = false;

    if (instance.current.touches.posY) {
      // 如果头部展开, 则隐藏头部
      instance.current.hideTop(); // 隐藏头部
    }
  } // 底部刷新


  function bottomRefresh() {
    // 如果没有设置刷新状态refreshing, 则不刷新
    if (refreshingRef.current !== true && refreshingRef.current !== false) {
      refreshed();
      return;
    } // 正在刷新不触发底部刷新


    if (refreshingRef.current === true) return; // 刷新完成触发底部刷新

    if (refreshingRef.current === false) {
      onBottomRefresh();
    }
  } // 控制刷新


  var pullRefreshTimeout = useRef();
  useEffect(function () {
    if (!instance.current) return; // 如果没有设置刷新状态refreshing, 则不刷新

    if (refreshingRef.current !== true && refreshingRef.current !== false) {
      refreshed();
      return;
    } // 正在刷新


    if (refreshingRef.current === true) {
      instance.current.isLoading = true;
      return;
    } // 刷新完成


    if (refreshingRef.current === false) {
      var _rootRef$current$clas;

      // 刷新完成, 重置状态
      refreshed(); // 判断是否没有滚动条, 如果没有滚动条会再次触发onBottomRefresh方法

      if (pullRefreshTimeout.current) {
        window.clearTimeout(pullRefreshTimeout.current);
      } // 底部刷新(1.无onBottomRefresh不触发底部刷新; 2.容器隐藏(className=hide)不触发底部刷新)


      if (!onBottomRefresh || !rootRef.current || ((_rootRef$current$clas = rootRef.current.classList) === null || _rootRef$current$clas === void 0 ? void 0 : _rootRef$current$clas.contains('hide'))) {
        return;
      } // 因为页面渲染需要时间, 所以需要等渲染完成后再判断有无滚动条


      pullRefreshTimeout.current = setTimeout(function () {
        if (!instance.current.hasScroll()) {
          console.log('刷新完成,但没有滚动条,继续加载...');
          bottomRefresh();
        } else if (instance.current.isBottom()) {
          console.log('刷新完成,滚动条在底部,继续加载...');
          bottomRefresh();
        }
      }, 500);
    }
  }, [refreshing]); // eslint-disable-line

  return /*#__PURE__*/React.createElement(Container, _extends({
    ref: rootRef
  }, others), /*#__PURE__*/React.createElement("div", {
    ref: topContainerRef,
    className: "SID-Dragrefresh-TopContainer containerpull-pull"
  }, /*#__PURE__*/React.createElement("div", {
    className: "containerpull-pull-box"
  }, /*#__PURE__*/React.createElement("div", {
    className: "containerpull-pull-icon"
  }), /*#__PURE__*/React.createElement("div", {
    className: "containerpull-pull-caption"
  }, locale('下拉可以刷新', 'pull_down')))), children);
});
export default ContainerPull;
